<?
/* QM Promisance - Turn-based strategy game
 * Copyright (C) 2001-2010 QMT Productions
 *
 * $URL: https://qmpromisance.svn.sourceforge.net/svnroot/qmpromisance/promisance/tags/release-4_4/classes/prom_html.php $
 * $Id: prom_html.php 1764 2010-10-01 01:13:32Z Quietust $
 */

if (!defined('IN_GAME'))
	die("Access denied");

abstract class prom_html
{
	protected $starttime;

	protected function getstyle ()
	{
		global $styles;
		return $styles[DEFAULT_STYLE]['file'];
	}

	// Global styles, overriding all stylesheets
	protected function addStyles ()
	{
?>
<style type="text/css">
#content { margin-left: 144px; }
#sidebar { position: absolute; top: 0; bottom: 0; left: 0; width: 144px; overflow: auto; }
body>#sidebar { position: fixed; }
</style>
<?
	}

	protected function addScripts ()
	{
?>
<script type="text/javascript">
//<![CDATA[
window.onload = function ()
{
	var tags = document.getElementsByTagName('a');
	for (var i = 0; i < tags.length; i++)
		if (tags[i].getAttribute('rel') == 'external')
			tags[i].target = '_blank';
	var logout = document.getElementById('logout');
	if (logout)
		logout.target = '_top';
}
function togglechecks (prefix)
{
	var tags = document.getElementsByTagName('input');
	for (var i = 0; i < tags.length; i++)
	{
		if ((tags[i].type == 'checkbox') && (tags[i].id.substring(0, prefix.length + 1) == prefix + '_'))
			tags[i].checked = !tags[i].checked;
	}
}
//]]>
</script>
<?
	}

	abstract public function begin ($title);
	abstract public function end ();
}

// Generates HTML for pages accessed while logged in
class prom_html_full extends prom_html
{
	protected $user, $empire;

	public function __construct ($user, $empire)
	{
		$this->user = $user;
		$this->empire = $empire;
	}

	protected function getstyle ()
	{
		global $styles;
		return $styles[$this->user->u_style]['file'];
	}

	public function begin ($title)
	{
		$this->starttime = microtime(TRUE);

		Header("Cache-Control: no-cache");
		Header("Expires: Thu, 01 Jan 1970 00:00:00 GMT");
		if (isset($_SERVER["HTTP_ACCEPT"]) && stristr($_SERVER["HTTP_ACCEPT"], "application/xhtml+xml"))
		{
			Header("Content-Type: application/xhtml+xml; charset=utf-8");
			echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
		}
		else	Header("Content-Type: text/html; charset=utf-8");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?=lang('LANG_CODE')?>" xml:lang="<?=lang('LANG_CODE')?>" dir="<?=lang('LANG_DIR')?>">
<head>
<title><?=lang('HTML_TITLE', $title)?></title>
<link rel="stylesheet" type="text/css" href="css/<?=$this->getstyle()?>" />
<?$this->addStyles();?>
<?$this->addScripts();?>
</head>
<body>
<div id="sidebar"><?$this->printMenuBar();?></div>
<div id="content" class="ac"><?
		$this->printBanner();
	}

	public function end ()
	{
		global $db;
		$dur = microtime(TRUE) - $this->starttime;
?>
<br /><?=lang('HTML_FOOTER', GAME_VERSION)?>
<br /><a href="?location=credits"><?=lang('HTML_LINK_CREDITS')?></a>
<?
		if (DEBUG_FOOTER)
			echo '<br /><br />'.lang('HTML_DEBUG_FOOTER', round($dur * 1000, 1), number(memory_get_usage()), number(memory_get_peak_usage()), $db->queryCount);
		else	echo '<!-- '. $dur .', '. memory_get_usage() .'/'. memory_get_peak_usage() .', '. $db->queryCount .' -->';
?>
</div>
</body>
</html>
<?
	}

	// Print the side menu
	private function printMenuBar ()
	{
?>
<h2 class="ac"><?=lang('MENU_HEADER_TOP')?></h2>
<table class="menus">
<tr><th><hr /><a href="?location=main"><?=lang('MENU_LINK_MAIN')?></a><hr /></th></tr>
<tr><th><?=lang('MENU_HEADER_INFO')?></th></tr>
<tr><td><b><a href="?location=guide"><?=lang('MENU_LINK_GUIDE')?></a></b></td></tr>
<tr><td><a href="?location=status"><?=lang('MENU_LINK_STATUS')?></a></td></tr>
<tr><td><a href="?location=scores"><?=lang('MENU_LINK_SCORES')?></a></td></tr>
<tr><td><a href="?location=graveyard"><?=lang('MENU_LINK_GRAVEYARD')?></a></td></tr>
<tr><td><a href="?location=search"><?=lang('MENU_LINK_SEARCH')?></a></td></tr>
<tr><td><a href="?location=news"><?=lang('MENU_LINK_NEWS')?></a></td></tr>
<?	if (CLAN_ENABLE) { ?>
<tr><td><a href="?location=contacts"><?=lang('MENU_LINK_CONTACTS')?></a></td></tr>
<tr><td><a href="?location=clanstats"><?=lang('MENU_LINK_CLANSTATS')?></a></td></tr>
<?	} ?>
<?	if (defined('URL_FORUMS')) {?>
<tr><td><a href="<?=URL_FORUMS?>" rel="external"><?=lang('MENU_LINK_FORUMS')?></a></td></tr>
<?	} ?>
<tr><th><?=lang('MENU_HEADER_TURNS')?></th></tr>
<tr><td><a href="?location=farm"><?=lang('MENU_LINK_FARM')?></a></td></tr>
<tr><td><a href="?location=cash"><?=lang('MENU_LINK_CASH')?></a></td></tr>
<tr><td><a href="?location=land"><?=lang('MENU_LINK_LAND')?></a></td></tr>
<tr><td><a href="?location=build"><?=lang('MENU_LINK_BUILD')?></a></td></tr>
<tr><th><?=lang('MENU_HEADER_MONEY')?></th></tr>
<tr><td><a href="?location=pvtmarketbuy"><?=lang('MENU_LINK_PVTMARKETBUY')?></a></td></tr>
<tr><td><a href="?location=pubmarketbuy"><?=lang('MENU_LINK_PUBMARKETBUY')?></a></td></tr>
<tr><td><a href="?location=bank"><?=lang('MENU_LINK_BANK')?></a></td></tr>
<tr><td><a href="?location=lottery"><?=lang('MENU_LINK_LOTTERY')?></a></td></tr>
<tr><th><?=lang('MENU_HEADER_FOREIGN')?></th></tr>
<?	if (AID_ENABLE) { ?>
<tr><td><a href="?location=aid"><?=lang('MENU_LINK_AID')?></a></td></tr>
<?	} ?>
<?	if (CLAN_ENABLE) { ?>
<tr><td><a href="?location=clan"><?=lang('MENU_LINK_CLAN')?></a></td></tr>
<?		if ($this->empire->c_id != 0) { ?>
<tr><td><a href="?location=clanforum"><?=lang('MENU_LINK_CLANFORUM')?></a></td></tr>
<?		} ?>
<?	} ?>
<tr><td><a href="?location=military"><?=lang('MENU_LINK_MILITARY')?></a></td></tr>
<tr><td><a href="?location=magic"><?=lang('MENU_LINK_MAGIC')?></a></td></tr>
<tr><th><?=lang('MENU_HEADER_MANAGE')?></th></tr>
<tr><td><a href="?location=messages"><?=lang('MENU_LINK_MESSAGES')?></a></td></tr>
<tr><td><a href="?location=manage"><?=lang('MENU_LINK_MANAGE')?></a></td></tr>
<tr><td><a href="?location=delete"><?=lang('MENU_LINK_DELETE')?></a></td></tr>
<?	if ($this->user->u_flags & UFLAG_ADMIN) { ?>
<tr><th><?=lang('MENU_HEADER_ADMIN')?></th></tr>
<tr><td><a href="?location=admin/users"><?=lang('MENU_LINK_ADMIN_USERS')?></a></td></tr>
<tr><td><a href="?location=admin/empires"><?=lang('MENU_LINK_ADMIN_EMPIRES')?></a></td></tr>
<?		if (CLAN_ENABLE) { ?>
<tr><td><a href="?location=admin/clans"><?=lang('MENU_LINK_ADMIN_CLANS')?></a></td></tr>
<?		} ?>
<tr><td><a href="?location=admin/market"><?=lang('MENU_LINK_ADMIN_MARKET')?></a></td></tr>
<tr><td><a href="?location=admin/messages"><?=lang('MENU_LINK_ADMIN_MESSAGES')?></a></td></tr>
<tr><td><a href="?location=admin/history"><?=lang('MENU_LINK_ADMIN_HISTORY')?></a></td></tr>
<tr><td><a href="?location=admin/round"><?=lang('MENU_LINK_ADMIN_ROUND')?></a></td></tr>
<tr><td><a href="?location=admin/log"><?=lang('MENU_LINK_ADMIN_LOG')?></a></td></tr>
<tr><td><a href="?location=admin/permissions"><?=lang('MENU_LINK_ADMIN_PERMISSIONS')?></a></td></tr>
<tr><td><a href="?location=admin/locks"><?=lang('MENU_LINK_ADMIN_LOCKS')?></a></td></tr>
<?	} elseif ($this->user->u_flags & UFLAG_MOD) { ?>
<tr><th><?=lang('MENU_HEADER_MODERATOR')?></th></tr>
<tr><td><a href="?location=admin/empires"><?=lang('MENU_LINK_ADMIN_EMPIRES')?></a></td></tr>
<tr><td><a href="?location=admin/messages"><?=lang('MENU_LINK_ADMIN_MESSAGES')?></a></td></tr>
<tr><td><a href="?location=admin/history"><?=lang('MENU_LINK_ADMIN_HISTORY')?></a></td></tr>
<?	} ?>
<tr><th><hr /><a href="?location=logout" id="logout"><?=lang('MENU_LINK_LOGOUT')?></a><hr /></th></tr>
</table>
<?
	}

	// Print a banner image or display a "Collect Bonus Turns" button if appropriate
	private function printBanner ()
	{
		global $banners, $page;
		if (count($banners) > 0)
		{
			$id = mt_rand(0, count($banners) - 1);
?>
<form method="post" action="?location=banner" id="bannerform">
<div>
<input type="hidden" name="action" value="click" />
<input type="hidden" name="banner_id" value="<?=$id?>" />
<input type="image" name="banner_img" src="<?=$banners[$id]['image']?>" alt="<?=$banners[$id]['label']?>" style="width:<?=$banners[$id]['width']?>px;height:<?=$banners[$id]['height']?>px;border:0" />
</div>
<script type="text/javascript">
//<![CDATA[
document.getElementById('bannerform').target = '_blank';
//]]>
</script>
</form>
<?
		}
		else
		{
			global $emp1;
			if (!isset($emp1))	// No empire loaded?
				return;	// Should be impossible, but just in case...
			if ($emp1->e_freeturns >= CUR_TIME)
				return;	// already got free turns
			if (!BONUS_TURNS)
				return;	// bonus turns not enabled
			if (!ROUND_STARTED)
				return;	// game not started, no turns to collect
?>
<form method="post" action="?location=banner">
<div>
<input type="hidden" name="action" value="bonus" />
<input type="hidden" name="bonus_return" value="<?=$page?>" />
<input type="submit" value="<?=lang('HTML_BONUS_SUBMIT')?>" />
</div>
</form>
<?
		}
	}
}

// Generates HTML for pages accessed while not logged in - no menubar/banner in the header, and include a "Return to Login" link in the footer
class prom_html_compact extends prom_html
{
	public function begin ($title)
	{
		$this->starttime = microtime(TRUE);

		Header("Cache-Control: no-cache");
		Header("Expires: Thu, 01 Jan 1970 00:00:00 GMT");
		if (isset($_SERVER["HTTP_ACCEPT"]) && stristr($_SERVER["HTTP_ACCEPT"], "application/xhtml+xml"))
		{
			Header("Content-Type: application/xhtml+xml; charset=utf-8");
			echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
		}
		else	Header("Content-Type: text/html; charset=utf-8");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?=lang('LANG_CODE')?>" xml:lang="<?=lang('LANG_CODE')?>" dir="<?=lang('LANG_DIR')?>">
<head>
<title><?=lang('HTML_TITLE', $title)?></title>
<link rel="stylesheet" type="text/css" href="css/<?=$this->getstyle()?>" />
<?$this->addStyles();?>
<?$this->addScripts();?>
</head>
<body>
<div class="ac">
<?
	}

	public function end ()
	{
		global $db, $page;
		$dur = microtime(TRUE) - $this->starttime;
?>
<br /><?=lang('HTML_FOOTER', GAME_VERSION)?>
<?
		if ($page != 'credits')
		{
?>
<br /><a href="?location=credits"><?=lang('HTML_LINK_CREDITS')?></a>
<?
		}
		if ($page != 'login')
		{
?>
<br /><a href="?location=login"><?=lang('HTML_LINK_LOGIN')?></a>
<?
		}
		if (DEBUG_FOOTER)
			echo '<br /><br />'.lang('HTML_DEBUG_FOOTER', round($dur * 1000, 1), number(memory_get_usage()), number(memory_get_peak_usage()), $db->queryCount);
		else	echo '<!-- '. $dur .', '. memory_get_usage() .'/'. memory_get_peak_usage() .', '. $db->queryCount .' -->';
?>
</div>
</body>
</html>
<?
	}
}
?>
