<?
/* QM Promisance - Turn-based strategy game
 * Copyright (C) 2001-2010 QMT Productions
 *
 * $URL: https://qmpromisance.svn.sourceforge.net/svnroot/qmpromisance/promisance/tags/release-4_4/pages/admin/log.php $
 * $Id: log.php 1764 2010-10-01 01:13:32Z Quietust $
 */

if (!defined('IN_GAME'))
	die("Access denied");

$title = 'ADMIN_LOG_TITLE';

$needpriv = UFLAG_ADMIN;

page_header();

// For compatibility with versions of PHP prior to 5.2, the constants E_RECOVERABLE_ERROR and E_DEPRECATED are not used below
// Since E_ERROR cannot be handled using the log handler, it is reused for empires flaged with EFLAG_LOGGED
$loglevels = array(
	0 => lang('ADMIN_LOG_LEVEL_EVENT'),
	E_ERROR => lang('ADMIN_LOG_LEVEL_LOGEVENT'),
	E_WARNING => lang('ADMIN_LOG_LEVEL_WARNING'),
	E_NOTICE => lang('ADMIN_LOG_LEVEL_NOTICE'),
	-1 => '',
	E_USER_ERROR => lang('ADMIN_LOG_LEVEL_CERROR'),
	E_USER_WARNING => lang('ADMIN_LOG_LEVEL_CWARNING'),
	E_USER_NOTICE => lang('ADMIN_LOG_LEVEL_CNOTICE'),
	-2 => '',
	E_STRICT => lang('ADMIN_LOG_LEVEL_STRICT'),
	4096 => lang('ADMIN_LOG_LEVEL_RECOVER'),
	8192 => lang('ADMIN_LOG_LEVEL_DEPRECATED'),
);

prom_session::initvar('admin_log_filter_before', 0);
prom_session::initvar('admin_log_filter_after', 0);
prom_session::initvar('admin_log_filter_levels', array());
prom_session::initvar('admin_log_filter_ip', '');
prom_session::initvar('admin_log_filter_page', '');
prom_session::initvar('admin_log_filter_action', '');
prom_session::initvar('admin_log_filter_locks', '');

if ($action == 'filter')
{
	$before = strtotime(getFormVar('log_filter_before'));
	if ($before == FALSE)
		$_SESSION['admin_log_filter_before'] = 0;
	else	$_SESSION['admin_log_filter_before'] = $before;

	$after = strtotime(getFormVar('log_filter_after'));
	if ($after == FALSE)
		$_SESSION['admin_log_filter_after'] = 0;
	else	$_SESSION['admin_log_filter_after'] = $after;

	$levels = getFormArr('log_filter_levels');
	$_SESSION['admin_log_filter_levels'] = array_intersect($levels, array_keys($loglevels));
	$_SESSION['admin_log_filter_ip'] = getFormVar('log_filter_ip');
	$_SESSION['admin_log_filter_page'] = getFormVar('log_filter_page');
	$_SESSION['admin_log_filter_action'] = getFormVar('log_filter_action');
	$_SESSION['admin_log_filter_locks'] = getFormVar('log_filter_locks');
}

if ($action == 'delete')
{
	$id = fixInputNum(getFormVar('log_last'));
	$q = $db->prepare('DELETE FROM '. LOG_TABLE .' WHERE log_id <= ?');
	$q->bindIntValue(1, $id);
	if ($q->execute())
		notice(lang('ADMIN_LOG_DELETE_SUCCESS'));
	else	notice(lang('ADMIN_LOG_DELETE_FAIL'));
	logevent();
}
notices();

$checks = array();
$values = array();

if ($_SESSION['admin_log_filter_before'] > 0)
{
	$checks[] = 'log_time <= ?';
	$values[] = $_SESSION['admin_log_filter_before'];
}
if ($_SESSION['admin_log_filter_after'] > 0)
{
	$checks[] = 'log_time >= ?';
	$values[] = $_SESSION['admin_log_filter_after'];
}
if (count($_SESSION['admin_log_filter_levels']) > 0)
{
	$filter = $_SESSION['admin_log_filter_levels'];
	$checks[] = 'log_type IN '. sqlArgList($filter);
	foreach ($filter as $val)
		$values[] = $val;
}
// Known issue - with PostgreSQL, trying to filter by something that isn't an IP address will generate query warnings
if ($_SESSION['admin_log_filter_ip'] != '')
{
	$filter = explode(' ', $_SESSION['admin_log_filter_ip']);
	$checks[] = 'log_ip IN '. sqlArgList($filter);
	foreach ($filter as $val)
		$values[] = $val;
}
if ($_SESSION['admin_log_filter_page'] != '')
{
	$filter = explode(' ', $_SESSION['admin_log_filter_page']);
	$checks[] = 'log_page IN '. sqlArgList($filter);
	foreach ($filter as $val)
		$values[] = $val;
}
if ($_SESSION['admin_log_filter_action'] != '')
{
	$filter = explode(' ', $_SESSION['admin_log_filter_action']);
	$checks[] = 'log_action IN '. sqlArgList($filter);
	foreach ($filter as $val)
		$values[] = $val;
}
// TODO - allow complex syntax for more detailed filtering (e.g. "e1,e2 e3,e4" for actions involving empires 1 and 2 OR empires 3 and 4)
if ($_SESSION['admin_log_filter_locks'] != '')
{
	$filter = explode(' ', $_SESSION['admin_log_filter_locks']);
	$checks[] = 'log_locks IN '. sqlArgList($filter);
	foreach ($filter as $val)
		$values[] = $val;
}

if (count($checks) > 0)
	$where = ' WHERE '. implode(' AND ', $checks);
else	$where = '';

prom_session::initvar('admin_log_sortcol', 'time');
prom_session::initvar('admin_log_sortdir', 'asc');
prom_session::initvar('admin_log_page', 1);

$sortcol = getFormVar('sortcol', $_SESSION['admin_log_sortcol']);
$sortdir = getFormVar('sortdir', $_SESSION['admin_log_sortdir']);
$curpage = fixInputNum(getFormVar('page', $_SESSION['admin_log_page']));
$per = 100;	// 100 rows per page

$last = $db->queryCell('SELECT MAX(log_id) FROM '. LOG_TABLE);
$total = $db->queryCell('SELECT COUNT(*) FROM '. LOG_TABLE . $where, $values);
$pages = ceil($total / $per);

$sorttypes = array(
	'_default'	=> 'time',
	'time'		=> array('log_time {DIR}, log_id ASC', 'log_time'),
	'type'		=> array('log_type {DIR}, log_id ASC', 'log_type'),
	'ip'		=> array('log_ip {DIR}, log_id ASC', 'log_ip'),
	'page'		=> array('log_page {DIR}, log_id ASC', 'log_page'),
	'action'	=> array('log_action {DIR}, log_id ASC', 'log_action'),
	'locks'		=> array('log_locks {DIR}, log_id ASC', 'log_locks'),
);
$sortby = parsesort($sortcol, $sortdir, $sorttypes);
$offset = parsepage($curpage, $total, $per);

$_SESSION['admin_log_sortcol'] = $sortcol;
$_SESSION['admin_log_sortdir'] = $sortdir;
$_SESSION['admin_log_page'] = $curpage;

$sortlink = '?location=admin/log&amp;';
?>
<form method="post" action="?location=admin/log">
<table class="inputtable">
<tr><th><?=lang('ADMIN_LOG_COLUMN_DATE')?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_TYPE')?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_IPADDR')?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_PAGE')?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_ACTION')?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_LOCKS')?></th>
    <th></th></tr>
<tr><td><?=lang('ADMIN_LOG_FILTER_BEFORE')?> <input type="text" name="log_filter_before" value="<?if ($_SESSION['admin_log_filter_before'] > 0) echo gmdate('Y/m/d H:i:s O', $_SESSION['admin_log_filter_before']); ?>" size="24" /><br />
        <?=lang('ADMIN_LOG_FILTER_AFTER')?> <input type="text" name="log_filter_after" value="<?if ($_SESSION['admin_log_filter_after'] > 0) echo gmdate('Y/m/d H:i:s O', $_SESSION['admin_log_filter_after']); ?>" size="24"  /></td>
    <td><?
$i = 0;
foreach ($loglevels as $level => $desc)
{
	if ($level < 0)
		echo '<br />';
	else	echo checkbox('log_filter_levels[]', $desc, $level, in_array($level, $_SESSION['admin_log_filter_levels'])) .' ';
}
?></td>
    <td><input type="text" name="log_filter_ip" value="<?=htmlspecialchars($_SESSION['admin_log_filter_ip'])?>" size="15"  /></td>
    <td><input type="text" name="log_filter_page" value="<?=htmlspecialchars($_SESSION['admin_log_filter_page'])?>" size="8"  /></td>
    <td><input type="text" name="log_filter_action" value="<?=htmlspecialchars($_SESSION['admin_log_filter_action'])?>" size="8"  /></td>
    <td><input type="text" name="log_filter_locks" value="<?=htmlspecialchars($_SESSION['admin_log_filter_locks'])?>" size="16"  /></td>
    <td><input type="hidden" name="action" value="filter" /><input type="submit" value="<?=lang('ADMIN_LOG_FILTER_SUBMIT')?>" /></td></tr>
</table>
</form>
<hr />
<table class="inputtable">
<tr><th><?=sortlink(lang('ADMIN_LOG_COLUMN_DATE'), $sortlink, $sortcol, $sortdir, 'time', 'desc', $curpage)?></th>
    <th><?=sortlink(lang('ADMIN_LOG_COLUMN_TYPE'), $sortlink, $sortcol, $sortdir, 'type', 'asc', $curpage)?></th>
    <th><?=sortlink(lang('ADMIN_LOG_COLUMN_IPADDR'), $sortlink, $sortcol, $sortdir, 'ip', 'asc', $curpage)?></th>
    <th><?=sortlink(lang('ADMIN_LOG_COLUMN_PAGE'), $sortlink, $sortcol, $sortdir, 'page', 'asc', $curpage)?></th>
    <th><?=sortlink(lang('ADMIN_LOG_COLUMN_ACTION'), $sortlink, $sortcol, $sortdir, 'action', 'asc', $curpage)?></th>
    <th><?=sortlink(lang('ADMIN_LOG_COLUMN_LOCKS'), $sortlink, $sortcol, $sortdir, 'locks', 'asc', $curpage)?></th>
    <th><?=lang('ADMIN_LOG_COLUMN_DATA')?></th></tr>
<?
$sql = 'SELECT * FROM '. LOG_TABLE . $where .' ORDER BY '. $sortby;
$sql = $db->setLimit($sql, $per, $offset);
$q = $db->prepare($sql);
$q->bindAllValues($values);
$q->execute() or warning('Failed to fetch log entries', 0);
$logs = $q->fetchAll();
foreach ($logs as $log)
{
?>
<tr><td><?=gmdate('Y/m/d H:i:s O', $log['log_time'])?></td>
    <td><?if (isset($loglevels[$log['log_type']])) echo $loglevels[$log['log_type']]; else echo lang('ADMIN_LOG_LEVEL_UNKNOWN');?></td>
    <td><?=$log['log_ip']?></td>
    <td><?=htmlspecialchars($log['log_page'])?></td>
    <td><?=htmlspecialchars($log['log_action'])?></td>
    <td><?=htmlspecialchars($log['log_locks'])?></td>
    <td><?=htmlspecialchars($log['log_text'])?></td></tr>
<?
}
if ($pages > 0)
{
?>
<tr><td colspan="7" class="ar"><?=pagelist($curpage, $pages, $sortlink, $sortcol, $sortdir)?><br />
<form method="post" action="?location=admin/log">
<div>
<input type="hidden" name="action" value="delete" />
<input type="hidden" name="log_last" value="<?=$last?>" />
<input type="submit" value="<?=lang('ADMIN_LOG_DELETE_SUBMIT')?>" />
</div>
</form>
</td></tr>
<?
}
else	echo '<tr><td colspan="7" class="ac">'. lang('ADMIN_LOG_NO_DATA') .'</td></tr>';
?>
</table>
<?
page_footer();
?>
